| Safe Haskell | None |
|---|---|
| Language | Haskell98 |
Data.ListTrie.Map.Ord
Description
A map from lists of elements that can be totally ordered to arbitrary values, based on a trie.
list-tries-0.6.0: Tries and Patricia tries: finite sets and maps for list keys
| Safe Haskell | None |
|---|---|
| Language | Haskell98 |
Data.ListTrie.Map.Ord
Description
A map from lists of elements that can be totally ordered to arbitrary values, based on a trie.